aboutsummaryrefslogtreecommitdiff
path: root/appservice
diff options
context:
space:
mode:
authorAndrew Morgan <1342360+anoadragon453@users.noreply.github.com>2019-07-12 16:43:01 +0100
committerGitHub <noreply@github.com>2019-07-12 16:43:01 +0100
commite2251199a49ab0bb846c02ba37e1cd437a7f725b (patch)
tree85487ef9deaf39a38f9e6ccf47dbc33e838c5dd8 /appservice
parent29841bed6b1a88787211368e6052a87a658c5714 (diff)
Lots of small typo fixes (#737)
Diffstat (limited to 'appservice')
-rw-r--r--appservice/api/query.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/appservice/api/query.go b/appservice/api/query.go
index 9ec21448..8ce3b4e0 100644
--- a/appservice/api/query.go
+++ b/appservice/api/query.go
@@ -134,9 +134,9 @@ func (h *httpAppServiceQueryAPI) UserIDExists(
return commonHTTP.PostJSON(ctx, span, h.httpClient, apiURL, request, response)
}
// RetreiveUserProfile is a wrapper that queries both the local database and
// application services for a given user's profile
-func RetreiveUserProfile(
+func RetrieveUserProfile(
ctx context.Context,
userID string,
asAPI AppServiceQueryAPI,
@@ -134,9 +134,9 @@ func (h *httpAppServiceQueryAPI) UserIDExists(
return commonHTTP.PostJSON(ctx, span, h.httpClient, apiURL, request, response)
}
-// RetreiveUserProfile is a wrapper that queries both the local database and
+// RetrieveUserProfile is a wrapper that queries both the local database and
// application services for a given user's profile